[arch-commits] Commit in ghc/trunk (PKGBUILD print-provides-replaces.sh)

2020-09-28 Thread Felix Yan via arch-commits
Date: Monday, September 28, 2020 @ 10:20:09
  Author: felixonmars
Revision: 712800

fix provides/replaces for some utils

Modified:
  ghc/trunk/PKGBUILD
  ghc/trunk/print-provides-replaces.sh

+
 PKGBUILD   |   19 +++
 print-provides-replaces.sh |   33 +
 2 files changed, 36 insertions(+), 16 deletions(-)

Modified: PKGBUILD
===
--- PKGBUILD2020-09-28 09:45:50 UTC (rev 712799)
+++ PKGBUILD2020-09-28 10:20:09 UTC (rev 712800)
@@ -69,10 +69,19 @@
 
 package_ghc() {
   pkgdesc='The Glasgow Haskell Compiler'
-  provides=("haskell-ghc=$pkgver")
-  replaces=("haskell-ghc")
   depends=('gcc' 'ghc-libs')
+  provides=('haskell-haddock=2.24.0'
+'haskell-hp2ps=0.1'
+'haskell-hpc-bin=0.68'
+'haskell-hsc2hs=0.68.7')
+  replaces=('haskell-haddock'
+'haskell-hp2ps'
+'haskell-hpc-bin'
+'haskell-hsc2hs')
 
+  provides+=("haskell-ghc=$pkgver")
+  replaces+=("haskell-ghc")
+
   cd ghc-$pkgver
   make DESTDIR="$pkgdir" -j1 install
 
@@ -99,6 +108,7 @@
 'haskell-base=4.14.1.0'
 'haskell-binary=0.8.8.0'
 'haskell-bytestring=0.10.10.0'
+'haskell-cabal=3.2.0.0'
 'haskell-containers=0.6.2.1'
 'haskell-deepseq=1.4.4.0'
 'haskell-directory=1.3.6.0'
@@ -125,11 +135,12 @@
 'haskell-transformers=0.5.6.2'
 'haskell-unix=2.7.2.2'
 'haskell-xhtml=3000.2.2.1'
-'haskell-cabal=3.2.0.0')
+'haskell-ghc-pkg=6.9')
   replaces=('haskell-array'
 'haskell-base'
 'haskell-binary'
 'haskell-bytestring'
+'haskell-cabal'
 'haskell-containers'
 'haskell-deepseq'
 'haskell-directory'
@@ -156,7 +167,7 @@
 'haskell-transformers'
 'haskell-unix'
 'haskell-xhtml'
-'haskell-cabal')
+'haskell-ghc-pkg')
 
   provides+=("haskell-ghci=$pkgver")
   conflicts+=('haskell-ghci')

Modified: print-provides-replaces.sh
===
--- PKGBUILD2020-01-08 15:50:03 UTC (rev 550299)
+++ PKGBUILD2020-01-08 16:10:01 UTC (rev 550300)
@@ -11,7 +11,7 @@
 
 pkgbase=ghc
 pkgname=(ghc-libs ghc ghc-static)
-pkgver=8.6.5
+pkgver=8.8.1
 pkgrel=1
 pkgdesc='The Glasgow Haskell Compiler'
 arch=('x86_64')
@@ -18,11 +18,11 @@
 url='https://www.haskell.org/ghc/'
 license=('custom')
 makedepends=('ghc-static' 'perl' 'libxslt' 'docbook-xsl' 'python-sphinx' 
'haskell-hscolour'
- 'texlive-bin' 'texlive-latexextra' 'ttf-dejavu')
+ 'texlive-bin' 'texlive-latexextra' 'ttf-dejavu' 'alex' 'happy' 
'time')
 
source=("https://downloads.haskell.org/~ghc/$pkgver/$pkgbase-${pkgver}-src.tar.xz;
 ghc-rebuild-doc-index.hook ghc-register.hook ghc-unregister.hook)
 noextract=("$pkgbase-${pkgver}-src.tar.xz")
-sha512sums=('c08a7480200cb99e1ffbe4ce7669f552b1054054966f7e7efcbc5f98af8032e1249fa391c4fc4c7d62cc8e0be5d17fa05845177f3cea3dbcf86e6c92d40fc0f9'
+sha512sums=('7268b012c3a6c34e7eac05c7d6959de6005651d33e870860bbfe589295502e8794a76580130b8f4da2f88032b68116dbbdbc4c1e900e0c862aaa9891fa788bef'
 
'afb119e4f665770c5704b97034d2488504eaa7afcddca2fb6b554079921cd2330599bcb5c36669f0d0e7856dd99ae1deeca1b0e97e2371a783f26e5ef9776ba9'
 
'bd65a369b618ec9bee46c028c2b6acff8f883f60f6cad6e5be8561fbcef6118278abec11bb86f9e6f92cb2e05ad74ec54611c1788e8ed95187d0091fcbbf8767'
 
'd4bfdd4c8ad9ac612cf187fec150850e9f4068a4a4202503c00dba07ba26f804bc11d7181249f7e3452d7ede60dc5dedea34e73fdb584ac2953068b51c6fd5ad')
@@ -95,36 +95,36 @@
   pkgdesc='The Glasgow Haskell Compiler - Dynamic Libraries'
   install='ghc.install'
   depends=('gmp' 'libffi' 'perl')
-  provides=('haskell-array=0.5.3.0'
-'haskell-base=4.12.0.0'
-'haskell-binary=0.8.6.0'
-'haskell-bytestring=0.10.8.2'
-'haskell-containers=0.6.0.1'
+  provides=('haskell-array=0.5.4.0'
+'haskell-base=4.13.0.0'
+'haskell-binary=0.8.7.0'
+'haskell-bytestring=0.10.9.0'
+'haskell-containers=0.6.2.1'
 'haskell-deepseq=1.4.4.0'
-'haskell-directory=1.3.3.0'
+'haskell-directory=1.3.3.2'
 'haskell-filepath=1.4.2.1'
-'haskell-ghc-boot=8.6.5'
-'haskell-ghc-boot-th=8.6.5'
+'haskell-ghc-boot=8.8.1'
+'haskell-ghc-boot-th=8.8.1'
 'haskell-ghc-compact=0.1.0.0'
-'haskell-ghc-heap=8.6.5'
+'haskell-ghc-heap=8.8.1'
 'haskell-ghc-prim=0.5.3'
-'haskell-haskeline=0.7.4.3'
+'haskell-haskeline=0.7.5.0'
 'haskell-hpc=0.6.0.3'
 'haskell-integer-gmp=1.0.2.0'
-'haskell-libiserv=8.6.3'
+'haskell-libiserv=8.8.1'
 'haskell-mtl=2.2.2'
-'haskell-parsec=3.1.13.0'
+'haskell-parsec=3.1.14.0'
 'haskell-pretty=1.1.3.6'
-'haskell-process=1.6.5.0'
+'haskell-process=1.6.5.1'
 'haskell-stm=2.5.0.0'
-'haskell-template-haskell=2.14.0.0'
-'haskell-terminfo=0.4.1.2'
-'haskell-text=1.2.3.1'
-'haskell-time=1.8.0.2'
+'haskell-template-haskell=2.15.0.0'
+'haskell-terminfo=0.4.1.4'
+'haskell-text=1.2.4.0'
+'haskell-time=1.9.3'
 'haskell-transformers=0.5.6.2'
 'haskell-unix=2.7.2.2'
 'haskell-xhtml=3000.2.2.1'
-'haskell-cabal=2.4.0.1')
+'haskell-cabal=3.0.0.0')
   replaces=('haskell-array'
 'haskell-base'
 'haskell-binary'

Modified: print-provides-replaces.sh
===
--- print-provides-replaces.sh  2020-01-08 15:50:03 UTC (rev 550299)
+++ print-provides-replaces.sh  2020-01-08 16:10:01 UTC (rev 550300)
@@ -23,7 +23,7 @@
 # $2 is the string for the test, either '=' or '<'
 print_var() {
   printf "  $1=("
-  for path in $(ls ./*/*.cabal); do
+  for path in $(ls ./*/*.cabal ./containers/containers/*.cabal); do
 dirname=$(echo $path | awk -F '/' '{ print $2 }')
 cabalfile=$(echo $path | awk -F '/' '{ print $3 }')
 cabalname=$(basename $cabalfile .cabal)


[arch-commits] Commit in ghc/trunk (PKGBUILD print-provides-replaces.sh)

2018-10-14 Thread Felix Yan via arch-commits
Date: Sunday, October 14, 2018 @ 12:24:57
  Author: felixonmars
Revision: 393465

upgpkg: ghc 8.6.1-1

Modified:
  ghc/trunk/PKGBUILD
  ghc/trunk/print-provides-replaces.sh

+
 PKGBUILD   |   38 +-
 print-provides-replaces.sh |7 +++
 2 files changed, 24 insertions(+), 21 deletions(-)

Modified: PKGBUILD
===
--- PKGBUILD2018-10-14 11:57:57 UTC (rev 393464)
+++ PKGBUILD2018-10-14 12:24:57 UTC (rev 393465)
@@ -11,7 +11,7 @@
 
 pkgbase=ghc
 pkgname=(ghc-libs ghc ghc-static)
-pkgver=8.4.3
+pkgver=8.6.1
 pkgrel=1
 pkgdesc='The Glasgow Haskell Compiler'
 arch=('x86_64')
@@ -22,7 +22,7 @@
 
source=("https://downloads.haskell.org/~ghc/$pkgver/$pkgbase-${pkgver}-src.tar.xz;
 ghc-rebuild-doc-index.hook ghc-register.hook ghc-unregister.hook)
 noextract=("$pkgbase-${pkgver}-src.tar.xz")
-sha512sums=('c6cea84264f32ae888f9931f834a1d721889242f656d14262e787ec54a1793d1862ce76daacaf1006c12b8af12919501afce1dc02571373e24830e4d51803414'
+sha512sums=('7979273bbd190c92057638db7a4ebcf98d2a31beed71489b308590c0ca034cb7cc8ab7e688c3c3c51bcae84d03b836eb2054e9bed25d2f359aa04bcc49db863a'
 
'afb119e4f665770c5704b97034d2488504eaa7afcddca2fb6b554079921cd2330599bcb5c36669f0d0e7856dd99ae1deeca1b0e97e2371a783f26e5ef9776ba9'
 
'bd65a369b618ec9bee46c028c2b6acff8f883f60f6cad6e5be8561fbcef6118278abec11bb86f9e6f92cb2e05ad74ec54611c1788e8ed95187d0091fcbbf8767'
 
'd4bfdd4c8ad9ac612cf187fec150850e9f4068a4a4202503c00dba07ba26f804bc11d7181249f7e3452d7ede60dc5dedea34e73fdb584ac2953068b51c6fd5ad')
@@ -96,33 +96,35 @@
   install='ghc.install'
   depends=('gmp' 'libffi' 'perl')
   provides=('haskell-array=0.5.2.0'
-'haskell-base=4.11.1.0'
-'haskell-binary=0.8.5.1'
+'haskell-base=4.12.0.0'
+'haskell-binary=0.8.6.0'
 'haskell-bytestring=0.10.8.2'
-'haskell-containers=0.5.11.0'
-'haskell-deepseq=1.4.3.0'
-'haskell-directory=1.3.1.5'
-'haskell-filepath=1.4.2'
-'haskell-ghc-boot=8.4.3'
-'haskell-ghc-boot-th=8.4.3'
+'haskell-containers=0.6.0.1'
+'haskell-deepseq=1.4.4.0'
+'haskell-directory=1.3.3.0'
+'haskell-filepath=1.4.2.1'
+'haskell-ghc-boot=8.6.1'
+'haskell-ghc-boot-th=8.6.1'
 'haskell-ghc-compact=0.1.0.0'
-'haskell-ghc-prim=0.5.2.0'
-'haskell-haskeline=0.7.4.2'
+'haskell-ghc-heap=8.6.1'
+'haskell-ghc-prim=0.5.3'
+'haskell-haskeline=0.7.4.3'
 'haskell-hpc=0.6.0.3'
 'haskell-integer-gmp=1.0.2.0'
+'haskell-libiserv=8.6.1'
 'haskell-mtl=2.2.2'
 'haskell-parsec=3.1.13.0'
 'haskell-pretty=1.1.3.6'
 'haskell-process=1.6.3.0'
-'haskell-stm=2.4.5.0'
-'haskell-template-haskell=2.13.0.0'
-'haskell-terminfo=0.4.1.1'
-'haskell-text=1.2.3.0'
+'haskell-stm=2.5.0.0'
+'haskell-template-haskell=2.14.0.0'
+'haskell-terminfo=0.4.1.2'
+'haskell-text=1.2.3.1'
 'haskell-time=1.8.0.2'
 'haskell-transformers=0.5.5.0'
 'haskell-unix=2.7.2.2'
 'haskell-xhtml=3000.2.2.1'
-'haskell-cabal=2.2.0.1')
+'haskell-cabal=2.4.0.1')
   replaces=('haskell-array'
 'haskell-base'
 'haskell-binary'
@@ -134,10 +136,12 @@
 'haskell-ghc-boot'
 'haskell-ghc-boot-th'
 'haskell-ghc-compact'
+'haskell-ghc-heap'
 'haskell-ghc-prim'
 'haskell-haskeline'
 'haskell-hpc'
 'haskell-integer-gmp'
+'haskell-libiserv'
 'haskell-mtl'
 'haskell-parsec'
 'haskell-pretty'

Modified: print-provides-replaces.sh
===
--- print-provides-replaces.sh  2018-10-14 11:57:57 UTC (rev 393464)
+++ print-provides-replaces.sh  2018-10-14 12:24:57 UTC (rev 393465)
@@ -22,7 +22,7 @@
 # $1 is the name of the variable
 # $2 is the string for the test, either '=' or '<'
 print_var() {
-  printf "$1=("
+  printf "  $1=("
   for path in $(ls ./*/*.cabal); do
 dirname=$(echo $path | awk -F '/' '{ print $2 }')
 cabalfile=$(echo $path | awk -F '/' '{ print $3 }')
@@ -31,14 +31,13 @@
 version=$(awk 'tolower($0) ~ /^version:/ {print $2 }' $path)
 printf "'haskell-$cabalname"
 [[ -n "$2" ]] && printf "$2$version"
-printf "'\n  "
+printf "'\n"
   done
   # also add cabal
   version=$(awk 'tolower($0) ~ /^version:/ { print $2 }' 
Cabal/Cabal/Cabal.cabal)
   printf "'haskell-cabal"
   [[ -n "$2" ]] && printf "$2$version"
-  printf "'\n  "
-  

[arch-commits] Commit in ghc/trunk (PKGBUILD print-provides-replaces.sh)

2014-07-14 Thread Thomas Dziedzic
Date: Monday, July 14, 2014 @ 08:24:51
  Author: td123
Revision: 216874

upgpkg: ghc 7.8.3-2

add missing provides due to ticket https://ghc.haskell.org/trac/ghc/ticket/8919 
getting fixed

Modified:
  ghc/trunk/PKGBUILD
  ghc/trunk/print-provides-replaces.sh

+
 PKGBUILD   |9 -
 print-provides-replaces.sh |5 -
 2 files changed, 8 insertions(+), 6 deletions(-)

Modified: PKGBUILD
===
--- PKGBUILD2014-07-14 04:25:18 UTC (rev 216873)
+++ PKGBUILD2014-07-14 06:24:51 UTC (rev 216874)
@@ -11,7 +11,7 @@
 
 pkgname=ghc
 pkgver=7.8.3
-pkgrel=1
+pkgrel=2
 pkgdesc='The Glasgow Haskell Compiler'
 arch=('i686' 'x86_64')
 url='http://www.haskell.org/ghc/'
@@ -45,6 +45,10 @@
   'haskell-transformers=0.3.0.0'
   'haskell-unix=2.7.0.1'
   'haskell-cabal=1.18.1.3'
+  'ghc=7.8.3-1'
+  'haskell-haskeline=0.7.1.2'
+  'haskell-terminfo=0.4.0.0'
+  'haskell-xhtml=3000.2.1'
  )
 replaces=('haskell-array'
   'haskell-base'
@@ -70,6 +74,9 @@
   'haskell-transformers'
   'haskell-unix'
   'haskell-cabal'
+  'haskell-haskeline'
+  'haskell-terminfo'
+  'haskell-xhtml'
  )
 source=(http://www.haskell.org/ghc/dist/${pkgver}/ghc-${pkgver}-src.tar.xz;
 
http://www.haskell.org/ghc/dist/${pkgver}/ghc-${pkgver}-testsuite.tar.xz;

Modified: print-provides-replaces.sh
===
--- print-provides-replaces.sh  2014-07-14 04:25:18 UTC (rev 216873)
+++ print-provides-replaces.sh  2014-07-14 06:24:51 UTC (rev 216874)
@@ -12,11 +12,6 @@
 exclude['Win32']=1
 # no integer-simple because we use integer-gmp
 exclude['integer-simple']=1
-# the rest are installed as dependencies of ghc and some shouldn't even be 
installed!
-# https://ghc.haskell.org/trac/ghc/ticket/8919
-exclude['haskeline']=1
-exclude['terminfo']=1
-exclude['xhtml']=1
 # extract excluded libraries from ghc.mk
 for exclude_pkg in $(sed 's/PKGS_THAT_ARE_INTREE_ONLY := //p' -n 
src/ghc-${pkgver}/ghc.mk); do
   exclude[${exclude_pkg}]=1
--- print-provides-replaces.sh  2020-09-28 09:45:50 UTC (rev 712799)
+++ print-provides-replaces.sh  2020-09-28 10:20:09 UTC (rev 712800)
@@ -17,28 +17,37 @@
   exclude[${exclude_pkg}]=1
 done
 
-cd src/ghc-${pkgver}/libraries
+cd src/ghc-${pkgver}
 
 # $1 is the name of the variable
 # $2 is the string for the test, either '=' or '<'
+# ..$@ are the files to search
 print_var() {
-  printf "  $1=("
-  for path in $(ls ./*/*.cabal ./containers/containers/*.cabal); do
+  field=$1
+  output_version=$2
+  shift
+  shift
+
+  printf "  $field=("
+  for path in $(ls $@); do
 dirname=$(echo $path | awk -F '/' '{ print $2 }')
 cabalfile=$(echo $path | awk -F '/' '{ print $3 }')
 cabalname=$(basename $cabalfile .cabal)
 [[ ${exclude[${dirname}]} ]] && continue
 version=$(awk 'tolower($0) ~ /^version:/ {print $2 }' $path)
-printf "'haskell-$cabalname"
-[[ -n "$2" ]] && printf "$2$version"
+printf "'haskell-${cabalname,,}"
+[[ -n "$output_version" ]] && printf "$output_version$version"
 printf "'\n"
   done
-  # also add cabal
-  version=$(awk 'tolower($0) ~ /^version:/ { print $2 }' 
Cabal/Cabal/Cabal.cabal)
-  printf "'haskell-cabal"
-  [[ -n "$2" ]] && printf "$2$version"
+  printf "\033[1A'haskell-${cabalname,,}"
+  [[ -n "$output_version" ]] && printf "$output_version$version"
   printf "')\n"
 }
 
-print_var 'provides' '='
-print_var 'replaces'
+# For ghc-libs
+print_var 'provides' '=' libraries/*/*.cabal 
libraries/{containers/containers,Cabal/Cabal}/*.cabal utils/ghc-pkg/*.cabal
+print_var 'replaces' '' libraries/*/*.cabal 
libraries/{containers/containers,Cabal/Cabal}/*.cabal utils/ghc-pkg/*.cabal
+
+# For ghc
+print_var 'provides' '=' utils/{hpc,hsc2hs,haddock*,hp2ps}/*.cabal
+print_var 'replaces' '' utils/{hpc,hsc2hs,haddock*,hp2ps}/*.cabal


[arch-commits] Commit in ghc/trunk (PKGBUILD print-provides-replaces.sh)

2020-01-08 Thread Felix Yan via arch-commits
Date: Wednesday, January 8, 2020 @ 16:10:01
  Author: felixonmars
Revision: 550300

upgpkg: ghc 8.8.1-1

Modified:
  ghc/trunk/PKGBUILD
  ghc/trunk/print-provides-replaces.sh

+
 PKGBUILD   |   42 +-
 print-provides-replaces.sh |2 +-
 2 files changed, 22 insertions(+), 22 deletions(-)
@@ -17,28 +17,37 @@
 
-# $1 is the name of the variable
+# $1 is the name of the field
 # $2 is the string for the test, either '=' or '<'

Modified: PKGBUILD
===